nltk.draw package
=================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.draw.cfg
   nltk.draw.dispersion
   nltk.draw.table
   nltk.draw.tree
   nltk.draw.util

Module contents
---------------

.. automodule:: nltk.draw
   :members:
   :undoc-members:
   :show-inheritance:
